@@ -130,7 +130,6 @@ int grid_load_from_buf(t_grid* grid, char* buf) {
 				if(resolve_symlinks == 1 && is_symlink(elem_of_line)) {
 					char* resolvBuf = realpath(elem_of_line, NULL);
 					if(NULL != resolvBuf) {
-						char* dest = malloc(sizeof(char)*strlen(resolvBuf)+1);
 						if(NULL == tofree) {
 							tofree = malloc(sizeof(char*));
 							if(NULL == tofree) {
@@ -149,8 +148,8 @@ int grid_load_from_buf(t_grid* grid, char* buf) {
 								tofree = np; 
 							}
 						}
+						char * dest = strdup(resolvBuf);
 						tofree[tofree_c++] = dest;
-						strncpy(dest, resolvBuf, strlen(resolvBuf)+1);
 						free(resolvBuf);
 						grid->elem[elem_cnt].value = dest;
 					}
